@@ -32,7 +32,7 @@ class Profile:
     """
 
     def __init__(
-        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=1000000, hot_pixel_threshold=200000
+        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=1000000, hot_pixel_threshold=200000, transpose=False
     ):
         self.scans = []
         try:
@@ -40,7 +40,7 @@ class Profile:
         except TypeError:
             pixel_max = [pixel_max] * len(file_paths)
         for i, f in enumerate(file_paths):
-            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], hot_pixel_threshold=hot_pixel_threshold))
+            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], hot_pixel_threshold=hot_pixel_threshold, transpose=transpose))
         self.q_vectors = None
         self.reflected_intensity = None
 
@@ -217,6 +217,7 @@ class Scan:
         energy=None,
         pixel_max=1000000,
         hot_pixel_threshold=200000
+        transpose=False,
     ):
         self.file_path = file_path
         self.metadata, self.data = parser(self.file_path)
@@ -245,6 +246,7 @@ class Scan:
         self.n_pixels = np.zeros(self.q.size)
         self.pixel_max = pixel_max
         self.hot_pixel_threshold = hot_pixel_threshold
+        self.transpose = transpose
 
     def __str__(self):
         """
@@ -324,7 +326,7 @@ class Scan:
                 if self.data['roi1_maxval'][i] > self.pixel_max:
                     to_remove.append(i)
                     continue
-                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold)
+                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold, transpose=self.transpose)
                 if crop_kwargs is None:
                     im.crop(crop_function)
                 else:
